<?php

/**
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * *PHP version 8.0
 *
 * Comments | core/comments.php.
 *
 * @category   Comments
 * @package    Clashvibes
 * @subpackage Comments
 * @author     Raymond Thompson <ray_thomp@hushmail.com>
 * @copyright  2017 Raymond Thompson
 * @license    http://www.gnu.org/licenses/gpl-3.0.en.html GPLv3
 * @version    GIT: https://github.com/raythompsonwebdev/clashvibes.git
 * @link       https://developer.wordpress.org/themes/basics/template-hierarchy/
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if (post_password_required() ) {
    return;
}
?>

<div id="comments" class="comments-area">

    <?php
    // You can start editing here -- including this comment!
    if (have_comments() ) :
        ?>
        <h2 class="comments-title">
        <?php
        $clashvibes_comment_count = get_comments_number();
        if ('1' === $clashvibes_comment_count ) {
            printf(
            /* translators: 1: title. */
                esc_html__('One thought on &ldquo;%1$s&rdquo;', 'clashvibes'),
                '<span>' . wp_kses_post(get_the_title()) . '</span>'
            );
        } else {
            printf(
            /* translators: 1: comment count number, 2: title. */
                esc_html(_nx('%1$s thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', $clashvibes_comment_count, 'comments title', 'clashvibes')),
                number_format_i18n($clashvibes_comment_count), // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                '<span>' . wp_kses_post(get_the_title()) . '</span>'
            );
        }
        ?>
        </h2><!-- .comments-title -->

        <?php the_comments_navigation(); ?>

        <ol class="comment-list">
        <?php
        wp_list_comments(
            array(
            'style'      => 'ol',
            'short_ping' => true,
            )
        );
        ?>
        </ol><!-- .comment-list -->

        <?php
        the_comments_navigation();

        // If comments are closed and there are comments, let's leave a little note, shall we?
        if (! comments_open() ) :
            ?>
            <p class="no-comments"><?php esc_html_e('Comments are closed.', 'clashvibes'); ?></p>
            <?php
        endif;

    endif; // Check for have_comments().

    comment_form();
    ?>

</div><!-- #comments -->
